@@ -1,4 +1,4 @@
-#[allow(missing_docs)]
+#![allow(missing_docs)]
 use error_chain::error_chain;
 
 impl From<Box<dyn std::error::Error>> for Error {
@@ -28,6 +28,7 @@ error_chain! {
     HexError(hex::FromHexError);
 
     ParseIntError(std::num::ParseIntError);
+    ParseFloatError(std::num::ParseFloatError);
     Secp256k1(bitcoin::secp256k1::Error);
     Bip32(bitcoin::util::bip32::Error);
     }
